Reference
=========

This reference manual details functions, modules, and objects included in bandicoot. For learning how to use bandicoot, see the :doc:`quickstart <../quickstart>`.


.. toctree::
   :maxdepth: 2

   bandicoot.individual
   bandicoot.spatial
   bandicoot.network
   bandicoot.recharge
   bandicoot.io
   bandicoot.core
   bandicoot.visualization
   bandicoot.others
   bandicoot.weekmatrix

